Class: Capybara::RackTest::Form::NilUploadedFile

Inherits:
Rack::Test::UploadedFile
  • Object
show all
Defined in:
lib/capybara/rack_test/form.rb

Overview

This only needs to inherit from Rack::Test::UploadedFile because Rack::Test checks for the class specifically when determining whether to construct the request as multipart. That check should be based solely on the form element's 'enctype' attribute value, which should probably be provided to Rack::Test in its non-GET request methods.

Instance Method Summary collapse

Constructor Details

#initialize ⇒ NilUploadedFile

rubocop:disable Lint/MissingSuper



9
10
11
12
# File 'lib/capybara/rack_test/form.rb', line 9

def initialize # rubocop:disable Lint/MissingSuper
  @empty_file = Tempfile.new('nil_uploaded_file')
  @empty_file.close
end

Instance Method Details

#append_to(_) ⇒ Object



19
# File 'lib/capybara/rack_test/form.rb', line 19

def append_to(_); end

#content_type ⇒ Object



15
# File 'lib/capybara/rack_test/form.rb', line 15

def content_type; 'application/octet-stream'; end

#original_filename ⇒ Object



14
# File 'lib/capybara/rack_test/form.rb', line 14

def original_filename; ''; end

#path ⇒ Object



16
# File 'lib/capybara/rack_test/form.rb', line 16

def path; @empty_file.path; end

#read ⇒ Object



18
# File 'lib/capybara/rack_test/form.rb', line 18

def read; ''; end

#set_encoding(_) ⇒ Object

rubocop:disable Naming/AccessorMethodName



20
# File 'lib/capybara/rack_test/form.rb', line 20

def set_encoding(_); end

#size ⇒ Object



17
# File 'lib/capybara/rack_test/form.rb', line 17

def size; 0; end