Class: Capybara::Selenium::Driver

Inherits:
Driver::Base show all
Defined in:
lib/capybara/selenium/driver.rb

Constant Summary collapse

DEFAULT_OPTIONS =
{
  :browser => :firefox
}
SPECIAL_OPTIONS =
[:browser]

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Driver::Base

#response_headers, #status_code

Constructor Details

#initialize(app, options = {}) ⇒ Driver

Returns a new instance of Driver.



27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
# File 'lib/capybara/selenium/driver.rb', line 27

def initialize(app, options={})
  begin
    require 'selenium-webdriver'
  rescue LoadError => e
    if e.message =~ /selenium-webdriver/
      raise LoadError, "Capybara's selenium driver is unable to load `selenium-webdriver`, please install the gem and add `gem 'selenium-webdriver'` to your Gemfile if you are using bundler."
    else
      raise e
    end
  end

  @app = app
  @browser = nil
  @exit_status = nil
  @frame_handles = {}
  @options = DEFAULT_OPTIONS.merge(options)
end

Instance Attribute Details

#appObject (readonly)

Returns the value of attribute app.



10
11
12
# File 'lib/capybara/selenium/driver.rb', line 10

def app
  @app
end

#optionsObject (readonly)

Returns the value of attribute options.



10
11
12
# File 'lib/capybara/selenium/driver.rb', line 10

def options
  @options
end

Instance Method Details

#accept_modal(type, options = {}, &blk) ⇒ Object



230
231
232
233
234
235
236
237
# File 'lib/capybara/selenium/driver.rb', line 230

def accept_modal(type, options={}, &blk)
  yield if block_given?
  modal = find_modal(options)
  modal.send_keys options[:with] if options[:with]
  message = modal.text
  modal.accept
  message
end

#browserObject



12
13
14
15
16
17
18
19
20
21
22
23
24
25
# File 'lib/capybara/selenium/driver.rb', line 12

def browser
  unless @browser
    @browser = Selenium::WebDriver.for(options[:browser], options.reject { |key,val| SPECIAL_OPTIONS.include?(key) })

    main = Process.pid
    at_exit do
      # Store the exit status of the test run since it goes away after calling the at_exit proc...
      @exit_status = $!.status if $!.is_a?(SystemExit)
      quit if Process.pid == main
      exit @exit_status if @exit_status # Force exit with stored status
    end
  end
  @browser
end

#browser_initialized?Boolean

Deprecated.

This method is being removed

Returns:

  • (Boolean)


267
268
269
# File 'lib/capybara/selenium/driver.rb', line 267

def browser_initialized?
  super && !@browser.nil?
end

#close_window(handle) ⇒ Object



189
190
191
192
193
# File 'lib/capybara/selenium/driver.rb', line 189

def close_window(handle)
  within_given_window(handle) do
    browser.close
  end
end

#current_urlObject



65
66
67
# File 'lib/capybara/selenium/driver.rb', line 65

def current_url
  browser.current_url
end

#current_window_handleObject



165
166
167
# File 'lib/capybara/selenium/driver.rb', line 165

def current_window_handle
  browser.window_handle
end

#dismiss_modal(type, options = {}, &blk) ⇒ Object



239
240
241
242
243
244
245
# File 'lib/capybara/selenium/driver.rb', line 239

def dismiss_modal(type, options={}, &blk)
  yield if block_given?
  modal = find_modal(options)
  message = modal.text
  modal.dismiss
  message
end

#evaluate_script(script) ⇒ Object



84
85
86
# File 'lib/capybara/selenium/driver.rb', line 84

def evaluate_script(script)
  browser.execute_script "return #{script}"
end

#execute_script(script) ⇒ Object



80
81
82
# File 'lib/capybara/selenium/driver.rb', line 80

def execute_script(script)
  browser.execute_script script
end

#find_css(selector) ⇒ Object



73
74
75
# File 'lib/capybara/selenium/driver.rb', line 73

def find_css(selector)
  browser.find_elements(:css, selector).map { |node| Capybara::Selenium::Node.new(self, node) }
end

#find_window(locator) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/capybara/selenium/driver.rb', line 208

def find_window(locator)
  handles = browser.window_handles
  return locator if handles.include? locator

  original_handle = browser.window_handle
  handles.each do |handle|
    switch_to_window(handle)
    if (locator == browser.execute_script("return window.name") ||
        browser.title.include?(locator) ||
        browser.current_url.include?(locator))
      switch_to_window(original_handle)
      return handle
    end
  end
  raise Capybara::ElementNotFound, "Could not find a window identified by #{locator}"
end

#find_xpath(selector) ⇒ Object



69
70
71
# File 'lib/capybara/selenium/driver.rb', line 69

def find_xpath(selector)
  browser.find_elements(:xpath, selector).map { |node| Capybara::Selenium::Node.new(self, node) }
end

#go_backObject



49
50
51
# File 'lib/capybara/selenium/driver.rb', line 49

def go_back
  browser.navigate.back
end

#go_forwardObject



53
54
55
# File 'lib/capybara/selenium/driver.rb', line 53

def go_forward
  browser.navigate.forward
end

#htmlObject



57
58
59
# File 'lib/capybara/selenium/driver.rb', line 57

def html
  browser.page_source
end

#invalid_element_errorsObject



255
256
257
258
259
260
# File 'lib/capybara/selenium/driver.rb', line 255

def invalid_element_errors
  [Selenium::WebDriver::Error::StaleElementReferenceError,
   Selenium::WebDriver::Error::UnhandledError,
   Selenium::WebDriver::Error::ElementNotVisibleError,
   Selenium::WebDriver::Error::InvalidSelectorError]  # Work around a race condition that can occur with chromedriver and #go_back/#go_forward
end

#maximize_window(handle) ⇒ Object



182
183
184
185
186
187
# File 'lib/capybara/selenium/driver.rb', line 182

def maximize_window(handle)
  within_given_window(handle) do
    browser.manage.window.maximize
  end
  sleep 0.1 # work around for https://code.google.com/p/selenium/issues/detail?id=7405
end

#needs_server?Boolean

Returns:

  • (Boolean)


78
# File 'lib/capybara/selenium/driver.rb', line 78

def needs_server?; true; end

#no_such_window_errorObject



262
263
264
# File 'lib/capybara/selenium/driver.rb', line 262

def no_such_window_error
  Selenium::WebDriver::Error::NoSuchWindowError
end

#open_new_windowObject



199
200
201
# File 'lib/capybara/selenium/driver.rb', line 199

def open_new_window
  browser.execute_script('window.open();')
end

#quitObject



247
248
249
250
251
252
253
# File 'lib/capybara/selenium/driver.rb', line 247

def quit
  @browser.quit if @browser
rescue Errno::ECONNREFUSED
  # Browser must have already gone
ensure
  @browser = nil
end

#reset!Object



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/capybara/selenium/driver.rb', line 92

def reset!
  # Use instance variable directly so we avoid starting the browser just to reset the session
  if @browser
    navigated = false
    start_time = Capybara::Helpers.monotonic_time
    begin
      if !navigated
        # Only trigger a navigation if we haven't done it already, otherwise it
        # can trigger an endless series of unload modals
        begin
          @browser.manage.delete_all_cookies
        rescue Selenium::WebDriver::Error::UnhandledError
          # delete_all_cookies fails when we've previously gone
          # to about:blank, so we rescue this error and do nothing
          # instead.
        end
        @browser.navigate.to("about:blank")
      end
      navigated = true

      #Ensure the page is empty and trigger an UnhandledAlertError for any modals that appear during unload
      until find_xpath("/html/body/*").empty? do
        raise Capybara::ExpectationNotMet.new('Timed out waiting for Selenium session reset') if (Capybara::Helpers.monotonic_time - start_time) >= 10
        sleep 0.05
      end
    rescue Selenium::WebDriver::Error::UnhandledAlertError
      # This error is thrown if an unhandled alert is on the page
      # Firefox appears to automatically dismiss this alert, chrome does not
      # We'll try to accept it
      begin
        @browser.switch_to.alert.accept
        sleep 0.25 # allow time for the modal to be handled
      rescue Selenium::WebDriver::Error::NoAlertPresentError
        # The alert is now gone - nothing to do
      end
      # try cleaning up the browser again
      retry
    end
  end
end

#resize_window_to(handle, width, height) ⇒ Object



176
177
178
179
180
# File 'lib/capybara/selenium/driver.rb', line 176

def resize_window_to(handle, width, height)
  within_given_window(handle) do
    browser.manage.window.resize_to(width, height)
  end
end

#save_screenshot(path, options = {}) ⇒ Object



88
89
90
# File 'lib/capybara/selenium/driver.rb', line 88

def save_screenshot(path, options={})
  browser.save_screenshot(path)
end

#switch_to_window(handle) ⇒ Object



203
204
205
# File 'lib/capybara/selenium/driver.rb', line 203

def switch_to_window(handle)
  browser.switch_to.window handle
end

#titleObject



61
62
63
# File 'lib/capybara/selenium/driver.rb', line 61

def title
  browser.title
end

#visit(path) ⇒ Object



45
46
47
# File 'lib/capybara/selenium/driver.rb', line 45

def visit(path)
  browser.navigate.to(path)
end

#wait?Boolean

Returns:

  • (Boolean)


77
# File 'lib/capybara/selenium/driver.rb', line 77

def wait?; true; end

#window_handlesObject



195
196
197
# File 'lib/capybara/selenium/driver.rb', line 195

def window_handles
  browser.window_handles
end

#window_size(handle) ⇒ Object



169
170
171
172
173
174
# File 'lib/capybara/selenium/driver.rb', line 169

def window_size(handle)
  within_given_window(handle) do
    size = browser.manage.window.size
    [size.width, size.height]
  end
end

#within_frame(index) ⇒ Object #within_frame(name_or_id) ⇒ Object #within_frame(element) ⇒ Object

Webdriver supports frame name, id, index(zero-based) or Node::Element to find iframe

Overloads:

  • #within_frame(index) ⇒ Object

    Parameters:

    • index (Integer)

      index of a frame

  • #within_frame(name_or_id) ⇒ Object

    Parameters:

    • name_or_id (String)

      name or id of a frame

  • #within_frame(element) ⇒ Object

    Parameters:



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/capybara/selenium/driver.rb', line 144

def within_frame(frame_handle)
  frame_handle = frame_handle.native if frame_handle.is_a?(Capybara::Node::Base)
  if !browser.switch_to.respond_to?(:parent_frame)
    # Selenium Webdriver < 2.43 doesnt support moving back to the parent
    @frame_handles[browser.window_handle] ||= []
    @frame_handles[browser.window_handle] << frame_handle
  end
  browser.switch_to.frame(frame_handle)
  yield
ensure
  if browser.switch_to.respond_to?(:parent_frame)
    browser.switch_to.parent_frame
  else
    # There doesnt appear to be any way in Selenium Webdriver < 2.43 to move back to a parent frame
    # other than going back to the root and then reiterating down
    @frame_handles[browser.window_handle].pop
    browser.switch_to.default_content
    @frame_handles[browser.window_handle].each { |fh| browser.switch_to.frame(fh) }
  end
end

#within_window(locator) ⇒ Object



225
226
227
228
# File 'lib/capybara/selenium/driver.rb', line 225

def within_window(locator)
  handle = find_window(locator)
  browser.switch_to.window(handle) { yield }
end