Class: Capybara::SessionConfig
- Inherits:
-
Object
- Object
- Capybara::SessionConfig
- Defined in:
- lib/capybara/session/config.rb
Constant Summary collapse
- OPTIONS =
i[always_include_port run_server default_selector default_max_wait_time ignore_hidden_elements automatic_reload match exact exact_text raise_server_errors visible_text_only automatic_label_click enable_aria_label save_path asset_host default_host app_host server_host server_port server_errors disable_animation test_id predicates_wait].freeze
Instance Method Summary collapse
-
#always_include_port ⇒ Object
See configure.
-
#app_host ⇒ Object
See configure.
- #app_host=(url) ⇒ Object
-
#asset_host ⇒ Object
See configure.
-
#automatic_label_click ⇒ Object
See configure.
-
#automatic_reload ⇒ Object
See configure.
-
#default_host ⇒ Object
See configure.
- #default_host=(url) ⇒ Object
-
#default_max_wait_time ⇒ Object
See configure.
-
#default_selector ⇒ Object
See configure.
-
#default_set_options ⇒ Object
See configure.
-
#disable_animation ⇒ Object
See configure.
- #disable_animation=(bool) ⇒ Object
-
#enable_aria_label ⇒ Object
See configure.
-
#exact ⇒ Object
See configure.
-
#ignore_hidden_elements ⇒ Object
See configure.
- #initialize_copy(other) ⇒ Object
-
#match ⇒ Object
See configure.
-
#raise_server_errors ⇒ Object
See configure.
-
#run_server ⇒ Object
See configure.
-
#save_path ⇒ Object
See configure.
-
#server_errors ⇒ Object
See configure.
- #server_errors=(errors) ⇒ Object
-
#server_host ⇒ String
The IP address bound by default server.
-
#server_port ⇒ Object
See configure.
-
#test_id ⇒ Object
See configure.
-
#test_id=(id) ⇒ Object
Set an attribue to be optionally matched against the locator for builtin selector types.
-
#visible_text_only ⇒ Object
See configure.
Instance Method Details
#always_include_port ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#app_host ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#app_host=(url) ⇒ Object
77 78 79 80 |
# File 'lib/capybara/session/config.rb', line 77 def app_host=(url) raise ArgumentError, "Capybara.app_host should be set to a url (http://www.example.com). Attempted to set #{url.inspect}." if url && url !~ URI::DEFAULT_PARSER.make_regexp @app_host = url end |
#asset_host ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#automatic_label_click ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#automatic_reload ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#default_host ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#default_host=(url) ⇒ Object
83 84 85 86 |
# File 'lib/capybara/session/config.rb', line 83 def default_host=(url) raise ArgumentError, "Capybara.default_host should be set to a url (http://www.example.com). Attempted to set #{url.inspect}." if url && url !~ URI::DEFAULT_PARSER.make_regexp @default_host = url end |
#default_max_wait_time ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#default_selector ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#default_set_options ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#disable_animation ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#disable_animation=(bool) ⇒ Object
89 90 91 92 |
# File 'lib/capybara/session/config.rb', line 89 def disable_animation=(bool) warn 'Capybara.disable_animation is a beta feature - it may change/disappear in a future point version' if bool @disable_animation = bool end |
#enable_aria_label ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#exact ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#ignore_hidden_elements ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#initialize_copy(other) ⇒ Object
107 108 109 110 |
# File 'lib/capybara/session/config.rb', line 107 def initialize_copy(other) super @server_errors = @server_errors.dup end |
#match ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#raise_server_errors ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#run_server ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#save_path ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#server_errors ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#server_errors=(errors) ⇒ Object
72 73 74 |
# File 'lib/capybara/session/config.rb', line 72 def server_errors=(errors) (@server_errors ||= []).replace(errors.dup) end |
#server_host ⇒ String
Returns The IP address bound by default server.
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#server_port ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#test_id ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |
#test_id=(id) ⇒ Object
Set an attribue to be optionally matched against the locator for builtin selector types. This attribute will be checked by builtin selector types whenever id would normally be checked. If nil then it will be ignored.
@params [String, Symbol, nil] id Name of the attribute to use as the test id
103 104 105 |
# File 'lib/capybara/session/config.rb', line 103 def test_id=(id) @test_id = id&.to_sym end |
#visible_text_only ⇒ Object
61 |
# File 'lib/capybara/session/config.rb', line 61 remove_method :server_host |