Class: Capybara::Selenium::Driver

Inherits:
Driver::Base show all
Defined in:
lib/capybara/selenium/driver.rb

Constant Summary collapse

DEFAULT_OPTIONS =
{
  :browser => :firefox
}
SPECIAL_OPTIONS =
[:browser]

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Driver::Base

#response_headers, #status_code

Constructor Details

#initialize(app, options = {}) ⇒ Driver

Returns a new instance of Driver.



26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
# File 'lib/capybara/selenium/driver.rb', line 26

def initialize(app, options={})
  begin
    require 'selenium-webdriver'
  rescue LoadError => e
    if e.message =~ /selenium-webdriver/
      raise LoadError, "Capybara's selenium driver is unable to load `selenium-webdriver`, please install the gem and add `gem 'selenium-webdriver'` to your Gemfile if you are using bundler."
    else
      raise e
    end
  end

  @app = app
  @browser = nil
  @exit_status = nil
  @frame_handles = {}
  @options = DEFAULT_OPTIONS.merge(options)
end

Instance Attribute Details

#appObject (readonly)

Returns the value of attribute app.



9
10
11
# File 'lib/capybara/selenium/driver.rb', line 9

def app
  @app
end

#optionsObject (readonly)

Returns the value of attribute options.



9
10
11
# File 'lib/capybara/selenium/driver.rb', line 9

def options
  @options
end

Instance Method Details

#accept_modal(type, options = {}, &blk) ⇒ Object



207
208
209
210
211
212
213
214
# File 'lib/capybara/selenium/driver.rb', line 207

def accept_modal(type, options={}, &blk)
  yield if block_given?
  modal = find_modal(options)
  modal.send_keys options[:with] if options[:with]
  message = modal.text
  modal.accept
  message
end

#browserObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
# File 'lib/capybara/selenium/driver.rb', line 11

def browser
  unless @browser
    @browser = Selenium::WebDriver.for(options[:browser], options.reject { |key,val| SPECIAL_OPTIONS.include?(key) })

    main = Process.pid
    at_exit do
      # Store the exit status of the test run since it goes away after calling the at_exit proc...
      @exit_status = $!.status if $!.is_a?(SystemExit)
      quit if Process.pid == main
      exit @exit_status if @exit_status # Force exit with stored status
    end
  end
  @browser
end

#close_window(handle) ⇒ Object



166
167
168
169
170
# File 'lib/capybara/selenium/driver.rb', line 166

def close_window(handle)
  within_given_window(handle) do
    browser.close
  end
end

#current_urlObject



64
65
66
# File 'lib/capybara/selenium/driver.rb', line 64

def current_url
  browser.current_url
end

#current_window_handleObject



142
143
144
# File 'lib/capybara/selenium/driver.rb', line 142

def current_window_handle
  browser.window_handle
end

#dismiss_modal(type, options = {}, &blk) ⇒ Object



216
217
218
219
220
221
222
# File 'lib/capybara/selenium/driver.rb', line 216

def dismiss_modal(type, options={}, &blk)
  yield if block_given?
  modal = find_modal(options)
  message = modal.text
  modal.dismiss
  message
end

#evaluate_script(script) ⇒ Object



83
84
85
# File 'lib/capybara/selenium/driver.rb', line 83

def evaluate_script(script)
  browser.execute_script "return #{script}"
end

#execute_script(script) ⇒ Object



79
80
81
# File 'lib/capybara/selenium/driver.rb', line 79

def execute_script(script)
  browser.execute_script script
end

#find_css(selector) ⇒ Object



72
73
74
# File 'lib/capybara/selenium/driver.rb', line 72

def find_css(selector)
  browser.find_elements(:css, selector).map { |node| Capybara::Selenium::Node.new(self, node) }
end

#find_window(locator) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

API:

  • private



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/capybara/selenium/driver.rb', line 185

def find_window(locator)
  handles = browser.window_handles
  return locator if handles.include? locator

  original_handle = browser.window_handle
  handles.each do |handle|
    switch_to_window(handle)
    if (locator == browser.execute_script("return window.name") ||
        browser.title.include?(locator) ||
        browser.current_url.include?(locator))
      switch_to_window(original_handle)
      return handle
    end
  end
  raise Capybara::ElementNotFound, "Could not find a window identified by #{locator}"
end

#find_xpath(selector) ⇒ Object



68
69
70
# File 'lib/capybara/selenium/driver.rb', line 68

def find_xpath(selector)
  browser.find_elements(:xpath, selector).map { |node| Capybara::Selenium::Node.new(self, node) }
end

#go_backObject



48
49
50
# File 'lib/capybara/selenium/driver.rb', line 48

def go_back
  browser.navigate.back
end

#go_forwardObject



52
53
54
# File 'lib/capybara/selenium/driver.rb', line 52

def go_forward
  browser.navigate.forward
end

#htmlObject



56
57
58
# File 'lib/capybara/selenium/driver.rb', line 56

def html
  browser.page_source
end

#invalid_element_errorsObject



232
233
234
# File 'lib/capybara/selenium/driver.rb', line 232

def invalid_element_errors
  [Selenium::WebDriver::Error::StaleElementReferenceError, Selenium::WebDriver::Error::UnhandledError, Selenium::WebDriver::Error::ElementNotVisibleError]
end

#maximize_window(handle) ⇒ Object



159
160
161
162
163
164
# File 'lib/capybara/selenium/driver.rb', line 159

def maximize_window(handle)
  within_given_window(handle) do
    browser.manage.window.maximize
  end
  sleep 0.1 # work around for https://code.google.com/p/selenium/issues/detail?id=7405
end

#needs_server?Boolean

Returns:



77
# File 'lib/capybara/selenium/driver.rb', line 77

def needs_server?; true; end

#no_such_window_errorObject



236
237
238
# File 'lib/capybara/selenium/driver.rb', line 236

def no_such_window_error
  Selenium::WebDriver::Error::NoSuchWindowError
end

#open_new_windowObject



176
177
178
# File 'lib/capybara/selenium/driver.rb', line 176

def open_new_window
  browser.execute_script('window.open();')
end

#quitObject



224
225
226
227
228
229
230
# File 'lib/capybara/selenium/driver.rb', line 224

def quit
  @browser.quit if @browser
rescue Errno::ECONNREFUSED
  # Browser must have already gone
ensure
  @browser = nil
end

#reset!Object



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/capybara/selenium/driver.rb', line 91

def reset!
  # Use instance variable directly so we avoid starting the browser just to reset the session
  if @browser
    begin
      begin @browser.manage.delete_all_cookies
      rescue Selenium::WebDriver::Error::UnhandledError
        # delete_all_cookies fails when we've previously gone
        # to about:blank, so we rescue this error and do nothing
        # instead.
      end
      @browser.navigate.to("about:blank")
    rescue Selenium::WebDriver::Error::UnhandledAlertError
      # This error is thrown if an unhandled alert is on the page
      # Firefox appears to automatically dismiss this alert, chrome does not
      # We'll try to accept it
      begin
        @browser.switch_to.alert.accept
      rescue Selenium::WebDriver::Error::NoAlertPresentError
        # The alert is now gone - nothing to do
      end
      # try cleaning up the browser again
      retry
    end
  end
end

#resize_window_to(handle, width, height) ⇒ Object



153
154
155
156
157
# File 'lib/capybara/selenium/driver.rb', line 153

def resize_window_to(handle, width, height)
  within_given_window(handle) do
    browser.manage.window.resize_to(width, height)
  end
end

#save_screenshot(path, options = {}) ⇒ Object



87
88
89
# File 'lib/capybara/selenium/driver.rb', line 87

def save_screenshot(path, options={})
  browser.save_screenshot(path)
end

#switch_to_window(handle) ⇒ Object



180
181
182
# File 'lib/capybara/selenium/driver.rb', line 180

def switch_to_window(handle)
  browser.switch_to.window handle
end

#titleObject



60
61
62
# File 'lib/capybara/selenium/driver.rb', line 60

def title
  browser.title
end

#visit(path) ⇒ Object



44
45
46
# File 'lib/capybara/selenium/driver.rb', line 44

def visit(path)
  browser.navigate.to(path)
end

#wait?Boolean

Returns:



76
# File 'lib/capybara/selenium/driver.rb', line 76

def wait?; true; end

#window_handlesObject



172
173
174
# File 'lib/capybara/selenium/driver.rb', line 172

def window_handles
  browser.window_handles
end

#window_size(handle) ⇒ Object



146
147
148
149
150
151
# File 'lib/capybara/selenium/driver.rb', line 146

def window_size(handle)
  within_given_window(handle) do
    size = browser.manage.window.size
    [size.width, size.height]
  end
end

#within_frame(index) ⇒ Object #within_frame(name_or_id) ⇒ Object #within_frame(element) ⇒ Object

Webdriver supports frame name, id, index(zero-based) or Element to find iframe

Overloads:

  • #within_frame(index) ⇒ Object

    Parameters:

    • index of a frame

  • #within_frame(name_or_id) ⇒ Object

    Parameters:

    • name or id of a frame

  • #within_frame(element) ⇒ Object

    Parameters:

    • frame element



128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/capybara/selenium/driver.rb', line 128

def within_frame(frame_handle)
  @frame_handles[browser.window_handle] ||= []
  frame_handle = frame_handle.native if frame_handle.is_a?(Capybara::Node::Base)
  @frame_handles[browser.window_handle] << frame_handle
  a=browser.switch_to.frame(frame_handle)
  yield
ensure
  # There doesnt appear to be any way in Webdriver to move back to a parent frame
  # other than going back to the root and then reiterating down
  @frame_handles[browser.window_handle].pop
  browser.switch_to.default_content
  @frame_handles[browser.window_handle].each { |fh| browser.switch_to.frame(fh) }
end

#within_window(locator) ⇒ Object



202
203
204
205
# File 'lib/capybara/selenium/driver.rb', line 202

def within_window(locator)
  handle = find_window(locator)
  browser.switch_to.window(handle) { yield }
end